% Andrea Miglio 03/02/2013
%
% Creates an array of intensity
%
% Input: 1: structure with with .degree, .freq, and .amp
%        2: array with the degree of the modes [0], [0 1], [0 1 2] that
%        you'd like to superpose
%        3: flag with phases: 0: all set to 0, 1: random phases 
%        4: totT: total time  (s)
%        5: fs=sampling frequency (in Hz)
%        6: conversion factor freq stars* conv_factor -> frequencies in the audible range
%
% Output: array with intensity

function intensity=create_starmusic(notes, degree, phase_flag, fs, totT, convF)

 % sampling period and time vector
 Ts = 1/fs;         % sampling period
 t = 0:Ts:totT;     % time vector
 
 % find modes of required degree
 idx=ismember(notes.degree,degree);
 
 % select modes
 freqs=notes.freq(idx>0);
 amp=notes.amp(idx>0);
  
 % rescale frequencines in audible range
 freqs=freqs*convF;
 
 % number of frequencies
 dim=numel(freqs);
 
 % define intensity vector 
 intensity.collective=zeros(1,numel(t));
 intensity.single=zeros(dim,numel(t));
 
 % phases
 switch phase_flag                          
     case 1 
         phi=2*pi*rand(dim,1);      % random phase for 1
     case 0 
         phi=zeros(dim,1);          %zero phase for 0
     otherwise
         error('phase_flag should be 0 or 1')
 end
 
 % superpose modes
 for j=1:dim
     intensity.single(j,:)=amp(j)*sin(2*pi*freqs(j)*t+phi(j));
     intensity.collective=intensity.collective+intensity.single(j,:);
 end
 
 % normalise
     norm=max(abs(intensity.collective));
     intensity.collective=intensity.collective/norm;
end