% Andrea Miglio 03/02/2013
% Emma Willett and Raphael Panayi 6-7/2017

% Script to generate .wav file from a list of frequencies

%%
clear     % clear workspace
clf       % clear figure

% Load file with frequencies - 1 is for the full spectrum 2 and 3 are for
% over-plotting the 1 peak data
files1=dir('./Models/Pick/*.dat');
nfile1=numel(files1);
files2=dir('./Models/Pick/1 Peak l=1/*.dat');
nfile2=numel(files2);
files3=dir('./Models/Pick/1 Peak l=2/*.dat');
nfile3=numel(files3);

% For setting plot limits
Llimit=[2250 650 190 18 19];
Ulimit=[4600 1350 400 40 40];

% Frequencies of maximum power for pitch matching 
numaxb=[3629.7899 1097.2190 291.5129 29.7659 32.0486];
numaxc=[3549.5590 1065.0329 300.0476 30.9881 29.3591];

for i=1:nfile1
  
filename1=['./Models/Pick/' files1(i).name];
x=char(files1(i).name);
notes1=read_starmusic(filename1);

filename2=['./Models/Pick/1 Peak l=1/' files2(i).name];
y=char(files2(i).name);
notes2=read_starmusic(filename2);

filename3=['./Models/Pick/1 Peak l=2/' files3(i).name];
z=char(files3(i).name);
notes3=read_starmusic(filename3);

fs = 44100;     % standard sampling rate

middleC=523.25;     %Hz    Used for pitch-matched mixed modes sound set
%middleC=1046.50;   %Hz    Used for radius sound set

numaxS=3090*1e-6;         %Hz solar numax

% Comment out one of the convF lines to generate radius or mixed mode sound set

% Conversion used for radius sound set
%convF=middleC/numaxS;

% Conversion used for pitch-matched mixed modes sound set. Set to numaxb to
% pitch match the l=1 set or numaxc to pitch match the l=2 set
convF=middleC/(numaxb(i)*1e-6);    

totT=5; % total s

degree=[0 1 2];     % Set to [0], [0 1] etc to select degrees to superpose
phase_flag=1;

% set to notes1 to play full spectrum, notes 2 to play l=1 central peak or
% notes 3 to play l=2 central peak
intensity=create_starmusic(notes2, degree, phase_flag, fs, totT, convF);

% Play sound
sound(intensity.collective,fs)

% Apply tapered cosine window
win = tukeywin(size(intensity.collective,2),0.1)';
intensity.collective = intensity.collective.*win;

% Write audio file
filenameO = [filename1, '.wav'];
audiowrite(filenameO,intensity.collective,fs,'BitsPerSample',32);

% Generate Plots
figure('Name', filename1)
subplot(2,3,1);
stem(notes1.freq(notes1.degree==0)*1e6, notes1.amp(notes1.degree==0), 'LineWidth', 1.0, 'Color', 'red');
title('l=0')
xlim([Llimit(i) Ulimit(i)])
ylim([0 1.01])
yticks([0 0.5])
yticklabels({})
xlabel('Frequency (\muHz)')
if i==1
    xticks([2500 3500 4500])
    xticklabels({2500 3500 4500})
elseif i==2
    xticks([700 1000 1300])
    xticklabels({700 1000 1300})
elseif i==3
    xticks([200 300 400])
    xticklabels({200 300 400})
else
    xticks([20 30 40])
    xticklabels({20 30 40})
end

subplot(2,3,2);
stem(notes1.freq(notes1.degree==1)*1e6, notes1.amp(notes1.degree==1), 'LineWidth', 1.0, 'Color', '[0 0.5 0]');
hold on     % Over-plot central peak
stem(notes2.freq(notes2.degree==1)*1e6, notes2.amp(notes2.degree==1), 'LineWidth', 1.0, 'Color', '[0.85 0.33 0.1]');
title('l=1')
xlim([Llimit(i) Ulimit(i)])
ylim([0 1.01])
yticks([0 0.5])
yticklabels({})
xlabel('Frequency (\muHz)')
if i==1
    xticks([2500 3500 4500])
    xticklabels({2500 3500 4500})
elseif i==2
    xticks([700 1000 1300])
    xticklabels({700 1000 1300})
elseif i==3
    xticks([200 300 400])
    xticklabels({200 300 400})
else
    xticks([20 30 40])
    xticklabels({20 30 40})
end

subplot(2,3,3);
stem(notes1.freq(notes1.degree==2)*1e6, notes1.amp(notes1.degree==2), 'LineWidth', 1.0, 'Color', '[0.08 0.17 0.55]');
hold on     % Over-plot central peak
stem(notes3.freq(notes3.degree==2)*1e6, notes3.amp(notes3.degree==2), 'LineWidth', 1.0, 'Color', '[0.85 0.33 0.1]');
title('l=2')
xlim([Llimit(i) Ulimit(i)])
ylim([0 1.01])
yticks([0 0.5])
yticklabels({})
xlabel('Frequency (\muHz)')
if i==1
    xticks([2500 3500 4500])
    xticklabels({2500 3500 4500})
elseif i==2
    xticks([700 1000 1300])
    xticklabels({700 1000 1300})
elseif i==3
    xticks([200 300 400])
    xticklabels({200 300 400})
else
    xticks([20 30 40])
    xticklabels({20 30 40})
end

subplot(2,3,[4,5,6]);   % Plot full spectrum
stem(notes1.freq(notes1.degree==0)*1e6, notes1.amp(notes1.degree==0),'LineWidth', 1.0, 'Color', 'red', 'DisplayName', 'l=0');
hold on
stem(notes1.freq(notes1.degree==1)*1e6, notes1.amp(notes1.degree==1),'LineWidth', 1.0, 'Color', '[0 0.5 0]', 'DisplayName', 'l=1');
hold on
stem(notes1.freq(notes1.degree==2)*1e6, notes1.amp(notes1.degree==2),'LineWidth', 1.0, 'Color', '[0.08 0.17 0.55]', 'DisplayName', 'l=2');
hold off
legend('show')
title('l=0,1,2')
xlim([Llimit(i) Ulimit(i)])
ylim([0 1.01])
yticks([0 0.5])
yticklabels({})
xlabel('Frequency (\muHz)')
if i==1
    xticks([2500 3500 4500])
    xticklabels({2500 3500 4500})
elseif i==2
    xticks([700 1000 1300])
    xticklabels({700 1000 1300})
elseif i==3
    xticks([200 300 400])
    xticklabels({200 300 400})
else
    xticks([20 30 40])
    xticklabels({20 30 40})
end

% Print plots to image file
orient(gcf, 'landscape')
print(gcf, '-depsc', [x,'tight.eps'])

% Wait until the end of each sound to play the next
pause(6);
end