% Andrea Miglio 03/02/2013
% Emma Willett and Raphael Panayi 6-7/2017

clear     % clear workspace
clf       % clear figure

% Temperatures and radii of models used on poster
%T=[5799.6 5312.5  4830.6  4433.0  4622.7]
%R=[0.954  1.774  3.421  11.158  10.862] 

% Colours used on poster (red, green, blue)
%C={[1 0 0], [0 0.5 0], [0.08 0.17 0.55]};
%%

rot=[2 5 10];   % set rotation rate (e-5 Hz)
for ii=1:numel(rot)
    M=1;        % stellar mass (in solar units)
    R=11.158;   % stellar radius (in solar units)
    T=4433.0;   % stellar temperature (in Kelvin)
        
    numax=3090*M/R^2/(T/5777)^0.5*1e-6;    % maximum oscillation power (Hz)
    
    split=0.1*1e-6*rot(ii);     %Frequency splitting
    Dnu=split;
    
    clear notes,
    n=1;    
    i=-n:1:n;
    notes.freq=numax+i*Dnu;
    notes.amp=ones(numel(notes.freq),1);                 
    notes.degree=1*ones(numel(notes.amp),1);                 
    
    totT=3;                   % total s (time of audio)
    fs = 44100;               % standard sampling rate
    Ts = 1/fs;                % sampling period
    t = 0:Ts:totT;            % time vector
    
    middleC=523.25;           %Hz

    convF=middleC/numax;      %factor to convert stellar osc. frequencies in audible range
    
    degree=[1];            
    phase_flag=0;
    
    intensity=create_starmusic(notes, degree, phase_flag, fs, totT, convF);

    % Apply tapered cosine window
    win = tukeywin(size(intensity.collective,2),0.5)';  
    intensity.collective = intensity.collective.*win/M;
    
    figure
    t = 0:Ts:totT;
     
    % need to subsample when plotting  
    sub_f=1;
    plot(t(1:sub_f:end),intensity.collective(1:sub_f:end), 'Color', [0.08 0.17 0.55], 'LineWidth' , 3)

    % set plot features
    xlim([0 3])
    ylim([-1.05 1.05])
     
    set(gca,'XTickLabel',[])
    set(gca,'YTickLabel',[])
    set(gca,'XTick', [])
    set(gca,'YTick', [])
    xlabel('Time')
    ylabel('Amplitude')
   
    if ii==1
        title  ('\Omega=0.2 \muHz (~58 days)')
elseif ii==2
        title  ('\Omega=0.5 \muHz (~24 days)')
    else
        title  ('\Omega=1.0 \muHz (~12 days)')
end
 
    figure(gcf)
    print('-dpng','-r300',gcf,['rotation plot',num2str(rot(ii)), '.png'])
    
    sound(intensity.collective,fs)  %%create sound
    pause(totT)

end
